@@ -270,8 +270,13 @@ KDE_NO_EXPORT bool MediaInfo::readChildDoc () {
             } while (!line.isNull ());
             NodePtr doc = node->document ();
             for (int i = 0; i < nr; i++)
-                if (!entries[i].url.isEmpty ())
-                    cur_elm->appendChild (new GenericURL (doc, URL::decode_string (entries[i].url), entries[i].title));
+                if (!entries[i].url.isEmpty ()) {
+                    GenericURL *gen = new GenericURL (doc,
+                            URL::decode_string (entries[i].url),
+                            entries[i].title);
+                    cur_elm->appendChild (gen);
+                    gen->opener = cur_elm;
+                }
             delete [] entries;
         } else if (line.stripWhiteSpace ().startsWith (Char ('<'))) {
             readXML (cur_elm, textstream, line);
@@ -296,7 +301,9 @@ KDE_NO_EXPORT bool MediaInfo::readChildDoc () {
                         else
                             title = mrl.mid (1);
                     } else if (!line.startsWith (Char ('#'))) {
-                        cur_elm->appendChild (new GenericURL (doc, mrl, title));
+                        GenericURL *gen = new GenericURL (doc, mrl, title);
+                        cur_elm->appendChild (gen);
+                        gen->opener = cur_elm;
                         title.truncate (0);
                     }
                 }
