@@ -114,7 +114,7 @@ KMPLAYER_NO_EXPORT void ASX::Entry::activate () {
             int pos = parseTimeString( s );
             if (pos > 0)
                 duration_timer = document()->post (
-                        this, new TimerPosting (pos * 10));
+                        new TimerPosting (this, pos * 10));
         }
     Mrl::activate ();
 }
