@@ -274,13 +274,9 @@ void ATOM::MediaGroup::addSummary (Node *rating_node) {
         out << "<smilText region=\"text\">";
         out << XMLStringlet (desc);
         out << String ("</smilText></par></body></smil>");
-        TextStream inxml (out.release ());
-        KMPlayer::readXML (this, inxml, String (), false);
-        NodePtr n = lastChild();
-        n->normalize ();
-        n->auxiliary_node = true;
-        removeChild (n);
-        insertBefore (n.ptr (), firstChild ());
+        insertBefore (out.release (), firstChild ());
+        if (firstChild () && SMIL::id_node_smil == firstChild ()->id)
+            firstChild ()->auxiliary_node = true;
 
     }
 }
