@@ -50,9 +50,8 @@ void FileDocument::readFromFile (const String & fn) {
     if (file.exists ()) {
         file.open (IO_ReadOnly);
         ByteArray data = file.readAll ();
-        TextStream inxml (data);
-        KMPlayer::readXML (this, inxml, String(), false);
-        normalize ();
+        if (data.size ())
+            insertBefore (String (data.data (), data.size ()), NULL);
     }
     load_tree_version = m_tree_version;
 }
@@ -113,6 +112,7 @@ KDE_NO_EXPORT void Recent::closed () {
         src = getAttribute (KMPlayer::StringPool::attr_url);
     if (title.isEmpty ())
         title = getAttribute (KMPlayer::StringPool::attr_title);
+    KMPlayer::Mrl::closed ();
 }
 
 KDE_NO_EXPORT void Recent::activate () {
@@ -137,12 +137,15 @@ KDE_NO_EXPORT KMPlayer::Node *Group::childFromTag (const String & tag) {
         return new Recent (m_doc, app);
     else if (tag == "group")
         return new Group (m_doc, app);
+    else if (tag == "object")
+        return new HtmlObject (m_doc, app, false);
     return NULL;
 }
 
 KDE_NO_EXPORT void Group::closed () {
     if (title.isEmpty ())
         title = getAttribute (KMPlayer::StringPool::attr_title);
+    KMPlayer::Title::closed ();
 }
 
 // gconftool -s -t string /apps/maemo/kmplayer/playlist_file /home/koos/playlist.xml
@@ -214,9 +217,7 @@ KDE_NO_EXPORT void PlaylistItemBase::activate () {
         }
         pl->setCaption (pn);
         //debugLog () << "cloning to " << data << endl;
-        TextStream inxml (data);
-        KMPlayer::readXML (pl, inxml, String(), false);
-        pl->normalize ();
+        pl->insertBefore (data, NULL);
         Node *cur = pl->firstChild ();
         pl->mrl ()->resolved = !!cur;
         if (parentNode ()->id == KMPlayer::id_node_group_node && cur) {
@@ -233,6 +234,7 @@ KDE_NO_EXPORT void PlaylistItemBase::activate () {
 KDE_NO_EXPORT void PlaylistItemBase::closed () {
     if (title.isEmpty ())
         title = getAttribute (KMPlayer::StringPool::attr_title);
+    KMPlayer::Mrl::closed ();
 }
 
 KDE_NO_CDTOR_EXPORT
@@ -286,6 +288,7 @@ KDE_NO_EXPORT KMPlayer::Node *PlaylistGroup::childFromTag (const String & tag) {
 KDE_NO_EXPORT void PlaylistGroup::closed () {
     if (title.isEmpty ())
         title = getAttribute (KMPlayer::StringPool::attr_title);
+    KMPlayer::Title::closed ();
 }
 
 KDE_NO_CDTOR_EXPORT
@@ -571,11 +574,9 @@ void Generator::readEvent (UnixProcess *) {
         unix_process->closeStdOut ();
         String s = data->release ();
         if (!s.isEmpty ()) {
-            TextStream inxml (s);
             Playlist *pl = new Playlist (m_control->m_app, m_control, true);
             NodePtr n = pl;
-            KMPlayer::readXML (n, inxml, String (), false);
-            pl->normalize ();
+            pl->insertBefore (s, NULL);
             pl->title = title;
             message (MsgInfoString, NULL);
             m_control->openDocument (n, NULL);
