@@ -63,7 +63,7 @@ public:
     void repaint (); // called whenever something changes on image
     Fit fit;        // how to layout images
     unsigned int duration; // cached attributes of head
-    Posting *duration_timer;
+    Command *duration_timer;
     SurfacePtrW rp_surface;
     int needs_scene_img;
 };
@@ -87,9 +87,9 @@ protected:
     void cancelTimers ();
     unsigned int start, duration;
     int steps, curr_step;
-    Posting *start_timer;
-    Posting *duration_timer;
-    Posting *update_timer;
+    Command *start_timer;
+    Command *duration_timer;
+    Command *update_timer;
     ConnectionPtr document_postponed;
 };
 
