@@ -71,7 +71,7 @@ public:
     void deactivate ();
     void *message (MessageType msg, void *content=NULL);
     NodePtrW enclosure;
-    Posting *timer;
+    Command *timer;
 };
 
 class KMPLAYER_NO_EXPORT Enclosure : public Mrl {
