@@ -234,6 +234,8 @@ void Control::deinit () {
 
     m_config->writeEntry (GCONF_KEY_VO, mplayer->hasXv () ? 0 : 1);
 
+    viewArea ()->deleteEvent ();
+
     delete media_server;
     delete mplayer;
 #ifdef __ARMEL__
@@ -1054,7 +1056,7 @@ void cb_favorites_add (Application *app) {
         msg = "No current selected";
     } else {
         Mrl *mrl = ctr->current_selected->mrl ();
-        if (!mrl || mrl->src.isEmpty ()) {
+        if (!mrl || mrl->src.isEmpty() || mrl->src.startsWith ("Playlist://")) {
             msg = "Not a valid link selected";
         } else {
             PlayListData *pd, *fav = NULL;
@@ -1073,18 +1075,14 @@ void cb_favorites_add (Application *app) {
                 NodePtr doc = mrl->document ();
                 if (!fav->document->mrl ()->resolved)
                     fav->document->activate (); // lazy load playlist
-                NodePtr n;
-                if (id_node_playlist_item == mrl->id) {
-                    n = mrl;
+                if (id_node_playlist_item == mrl->id ||
+                        id_node_html_object == mrl->id) {
+                    fav->document->insertBefore (mrl->outerXML (false), NULL);
                 } else {
-                    n = new PlaylistItem (doc, app, false, mrl->src);
+                    NodePtr n = new PlaylistItem (doc, app, false, mrl->src);
                     n->setCaption (mrl->title);
+                    fav->document->appendChild (n);
                 }
-                String xml = n->outerXML ();
-                TextStream inxml ((const char *) xml);
-                readXML (fav->document, inxml, String(), false);
-                if (fav->document->lastChild ())
-                    fav->document->lastChild ()->normalize ();
                 updateTree (app, fav->id);
             }
         }
@@ -1139,15 +1137,15 @@ void newFile (Application * app) {
 
 gboolean cb_mainview_delete (GtkObject *, GdkEvent *, Application *app) {
     CONTROL(app)->deinit ();
-    gtk_main_quit ();
     debugLog () << "delete" << endl;
+    gtk_main_quit ();
     return false;
 }
 
 void cb_mainview_close (GtkObject *, Application *app) {
     CONTROL(app)->deinit ();
-    gtk_main_quit ();
     debugLog () << "close" << endl;
+    gtk_main_quit ();
 }
 
 static bool testFullscreenPlaylist (Application *app) {
