@@ -116,7 +116,7 @@ public:
     NodePtr playlists;
     NodePtr recents;
 
-    String copyPasteUrl;
+    String copyPasteXml;
     NodePtr copyPasteNode;
 
     PlayListData *playlist_data;
