@@ -269,6 +269,20 @@ void TreeNode<Node>::removeChild (NodePtr c) {
     removeChildImpl (c);
 }
 
+KDE_NO_EXPORT void Node::insertBefore (const String &xml, Node *b) {
+    Node *last = lastChild ();
+    TextStream inxml ((const char *) xml);
+    readXML (this, inxml, String(), false);
+    if (lastChild () != last) {
+        NodePtr n = lastChild ();
+        n->normalize ();
+        if (b) {
+            removeChild (n);
+            insertBefore (n, b);
+        }
+    }
+}
+
 KDE_NO_EXPORT void Node::replaceChild (NodePtr _new, NodePtr old) {
     document()->m_tree_version++;
     if (old->m_prev) {
@@ -334,7 +348,8 @@ String Node::innerText () const {
     return out.release ();
 }
 
-static void getOuterXML (const Node *p, TextStream & out, int depth) {
+static
+void getOuterXML (const Node *p, TextStream & out, int depth, bool inter) {
     if (!p->isElementNode ()) { // #text or #cdata
         if (p->id == id_node_cdata)
             out << "<![CDATA[" << p->nodeValue () << "]]>" << char_nl;
@@ -349,8 +364,11 @@ static void getOuterXML (const Node *p, TextStream & out, int depth) {
                 "=\"" << XMLStringlet (a->value ()) << "\"";
         if (e->hasChildNodes ()) {
             out << char_gt << char_nl;
-            for (Node *c = e->firstChild (); c; c = c->nextSibling ())
-                getOuterXML (c, out, depth + 1);
+            for (Node *c = e->firstChild (); c; c = c->nextSibling ()) {
+                if (!inter && c->mrl () && c->mrl ()->opener.ptr () == e)
+                    continue;
+                getOuterXML (c, out, depth + 1, inter);
+            }
             out << indent << String("</") << XMLStringlet (e->nodeName()) <<
                 char_gt << char_nl;
         } else
@@ -361,13 +379,13 @@ static void getOuterXML (const Node *p, TextStream & out, int depth) {
 String Node::innerXML () const {
     TextStream out;
     for (Node *e = firstChild (); e; e = e->nextSibling ())
-        getOuterXML (e, out, 0);
+        getOuterXML (e, out, 0, true);
     return out.release ();
 }
 
-String Node::outerXML () const {
+String Node::outerXML (bool inter) const {
     TextStream out;
-    getOuterXML (this, out, 0);
+    getOuterXML (this, out, 0, inter);
     return out.release ();
 }
 
@@ -1708,7 +1726,8 @@ void SimpleSAXParser::push_attribute () {
 
 bool SimpleSAXParser::nextToken () {
     TokenInfoPtr cur_token = token;
-    while (!data->atEnd () && cur_token == token && !(token && token->next)) {
+    while ((have_next_char || !data->atEnd ()) &&
+           cur_token == token && !(token && token->next)) {
         const gchar *at = NULL;
         if (have_next_char) {
             have_next_char = false;
