@@ -345,7 +345,7 @@ public:
     void characterData (const String & s);
     String innerText () const;
     String innerXML () const;
-    String outerXML () const;
+    String outerXML (bool inter_doc=true) const;
     virtual const char * nodeName () const;
     virtual String nodeValue () const;
 
@@ -435,6 +435,8 @@ public:
     virtual void reset ();
     virtual void clear ();
     void clearChildren ();
+    using TreeNode<Node>::insertBefore;
+    void insertBefore (const String &xml, Node *b);
     void replaceChild (NodePtr _new, NodePtr old);
     /*
      * Get rid of whitespace only text nodes
@@ -932,18 +934,17 @@ template <class T> inline void List<T>::insertBefore (T *c, T *b) {
 
 template <class T> inline void List<T>::removeImpl (T *c) {
     typename Item<T>::SharedType s = c->m_self;
-    if (c->m_prev) {
+    if (c->m_prev)
         c->m_prev->m_next = c->m_next;
-        c->m_prev = 0L;
-    } else {
+    else
         m_first = c->m_next;
-    }
     if (c->m_next) {
         c->m_next->m_prev = c->m_prev;
         c->m_next = 0L;
     } else {
         m_last = c->m_prev;
     }
+    c->m_prev = 0L;
 }
 
 template <class T> inline void List<T>::remove (T *c) {
