@@ -738,10 +738,13 @@ void cb_playlistMenuActivate (GtkButton * button, Application * app) {
                 //node->id == id_node_group_node ||
                 node->id == id_node_playlist_item ||
                 node->id == id_node_html_object ||
-                (pld->id == 0 && node->mrl () &&
-                 node->id != id_node_playlist_document && node->mrl ()->src);
+                (pld->id == 0 &&
+                 node->mrl () &&
+                 node->id != id_node_playlist_document &&
+                 !node->mrl ()->src.isEmpty ());
             show_paste = pld->id == app->playlists_tree_id &&
-                (!CONTROL(app)->copyPasteUrl.isEmpty () || CONTROL(app)->copyPasteNode);
+                (!CONTROL(app)->copyPasteXml.isEmpty () ||
+                 CONTROL(app)->copyPasteNode);
             show_cut = pld->id == app->playlists_tree_id &&
                 gtk_tree_path_get_depth (path) > 1;
             show_title = pld->id == app->playlists_tree_id &&
@@ -764,7 +767,21 @@ void cb_playlistCopy (GtkButton * button, Application * app) {
         Node *node = getNode (pld, path);
         if (node && node->mrl ()) {
             CONTROL(app)->copyPasteNode = 0L;
-            CONTROL(app)->copyPasteUrl = node->mrl ()->src;
+            if (node->id == id_node_recent_node ||
+                    node->id == id_node_playlist_item ||
+                    node->id == id_node_html_object) {
+                CONTROL(app)->copyPasteXml = node->outerXML (false);
+            } else {
+                TextStream txt;
+                txt << "<item url=\""
+                    << XMLStringlet (node->mrl ()->src)
+                    << "\"/>";
+                CONTROL(app)->copyPasteXml = txt.release ();
+            }
+            gtk_clipboard_set_text (gtk_clipboard_get_for_display (
+                        gtk_widget_get_display (GTK_WIDGET (button)),
+                        GDK_SELECTION_CLIPBOARD),
+                    (const char *)node->mrl ()->src, -1);
         }
     }
 }
@@ -775,13 +792,25 @@ void cb_playlistPaste (GtkButton * button, Application * app) {
     if (pld) {
         Node *node = getNode (pld, path);
         if (node && pld->id == app->playlists_tree_id) {
-            Node *newnode = CONTROL(app)->copyPasteNode
-                ? CONTROL(app)->copyPasteNode.ptr ()
-                : new PlaylistItem(pld->document, app, false,CONTROL(app)->copyPasteUrl);
-            if (gtk_tree_path_get_depth (path) == 1)
-                node->insertBefore (newnode, node->firstChild ());
-            else
-                node->parentNode ()->insertBefore (newnode, node);
+            Node *newnode = CONTROL(app)->copyPasteNode;
+            if (newnode) {
+                if (gtk_tree_path_get_depth (path) == 1)
+                    node->insertBefore (newnode, node->firstChild ());
+                else
+                    node->parentNode ()->insertBefore (newnode, node);
+            } else if (!CONTROL(app)->copyPasteXml.isEmpty ()) {
+                if (gtk_tree_path_get_depth (path) == 1) {
+                    node->insertBefore (
+                            CONTROL(app)->copyPasteXml, node->firstChild ());
+                    newnode = node->firstChild ();
+                } else {
+                    node->parentNode ()->insertBefore (
+                            CONTROL(app)->copyPasteXml, node);
+                    newnode = node->previousSibling ();
+                }
+            }
+            static_cast <Element *> (newnode)->setAttribute (
+                    "clipBegin", String ());
             pld->current = newnode;
             updateTree (app, app->playlists_tree_id);
         }
@@ -827,15 +856,20 @@ void cb_playlistPasteInNewGroup (GtkButton * button, Application * app) {
             String grp = getUserInput (app,
                     "New Group", "Enter name of the group", NULL);
             if (!grp.isNull ()) {
-                Node *newnode = new Group (pld->document, app, grp);
-                newnode->appendChild (CONTROL(app)->copyPasteNode
-                        ? CONTROL(app)->copyPasteNode.ptr ()
-                        : new PlaylistItem (pld->document, app, false, CONTROL(app)->copyPasteUrl));
+                NodePtr group = new Group (pld->document, app, grp);
+                if (CONTROL(app)->copyPasteNode) {
+                    group->appendChild (CONTROL(app)->copyPasteNode);
+                } else if (!CONTROL(app)->copyPasteXml.isEmpty ()) {
+                    group->insertBefore (CONTROL(app)->copyPasteXml, NULL);
+                    if (group->firstChild ())
+                        static_cast <Element *> (group->firstChild ())->
+                            setAttribute ("clipBegin", String ());
+                }
                 if (gtk_tree_path_get_depth (path) == 1)
-                    node->insertBefore (newnode, node->firstChild ());
+                    node->insertBefore (group, node->firstChild ());
                 else
-                    node->parentNode ()->insertBefore (newnode, node);
-                pld->current = newnode;
+                    node->parentNode ()->insertBefore (group, node);
+                pld->current = group;
                 updateTree (app, app->playlists_tree_id);
             }
         }
@@ -850,7 +884,7 @@ void cb_playlistCut (GtkButton * button, Application * app) {
         if (node &&
                 pld->id == app->playlists_tree_id &&
                 gtk_tree_path_get_depth (path) > 1) {
-            CONTROL(app)->copyPasteUrl.clear ();
+            CONTROL(app)->copyPasteXml.clear ();
             CONTROL(app)->copyPasteNode = node;
             if (node->previousSibling ())
                 pld->current = node->previousSibling ();
@@ -960,9 +994,7 @@ void cb_playlist_edit_commit (GtkButton * button, Application * app) {
                 node->removeChild (c);
                 tmp->appendChild (c.ptr ());
             }
-            TextStream xmldata;
-            xmldata << str;
-            readXML (node, xmldata, String (), false);
+            node->insertBefore (str, NULL);
             updateTree (app, pld->id);
         } else
             warningLog() << "No node selected" << endl;
