@@ -400,7 +400,7 @@ KMPLAYER_NO_EXPORT bool MPlayer::play (NodePtr node) {
         return false;
     }
     request_seek = NO_SEEK;
-    String wd ("/home/user");
+    String wd (getenv ("HOME"));
     URL url (m_url);
     is_local_file = url.isLocalFile ();
     if (is_local_file) {
@@ -430,7 +430,7 @@ KMPLAYER_NO_EXPORT bool MPlayer::play (NodePtr node) {
     cmdline += String (buf);
     Mrl *mrl = this->mrl ();
     if (mrl->repeat > 0)
-        cmdline += String (" -loop ") + String::number (mrl->repeat+1);
+        cmdline += String (" -loop ") + String::number (mrl->repeat);
     if (is_local_file && mrl->clip_begin > 100)
         cmdline += String (" -ss ") + String::number (mrl->clip_begin/100);
     cmdline += Char (' ');
