@@ -1085,7 +1085,7 @@ void CurlGetJob::init (IOJob *job) {
         curl_easy_setopt (easy, CURLOPT_HTTPHEADER, headers);
     //if (!strncmp (u, "http", 4))
     //    curl_easy_setopt (easy, CURLOPT_HTTPGET, true);
-    if (CON_IC_STATUS_CONNECTED == ic_status) {
+    if (CON_IC_STATUS_CONNECTED == ic_status || URL (url).isLocalFile ()) {
         start ();
     } else {
         if (!ic_connect_request)
