@@ -1692,6 +1692,13 @@ KDE_NO_EXPORT void ViewArea::resizeEvent () {
         setAudioVideoGeometry (IRect (x, y, w, h), 0L);
 }
 
+KDE_NO_EXPORT void ViewArea::deleteEvent () {
+    widget = NULL;
+    if (m_repaint_timer)
+        g_source_remove (m_repaint_timer);
+    m_repaint_timer = 0;
+}
+
 KDE_NO_EXPORT
 void ViewArea::setAudioVideoGeometry (const IRect &rect, unsigned int * bg_color) {
     int x = rect.x (), y = rect.y (), w = rect.width (), h = rect.height ();
@@ -1873,6 +1880,8 @@ KDE_NO_EXPORT bool ViewArea::timeoutPaintEvent () {
 }
 
 bool ViewArea::scheduleRepaintTimeout (unsigned int cur_time) {
+    if (!widget)
+        return false;
     int timeout;
     if (!cur_time) {
         timeout = 20;
